Environment enum

Environment enumeration for different deployment stages

Example:

const environment = Environment.production;

if (environment.isDevelopment) {
  print('Debug mode enabled');
}
Inheritance
Available extensions

Values

development → const Environment
staging → const Environment
production → const Environment

Properties

displayName → String
Get a user-friendly name
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isDevelopment → bool
Check if current environment is development
no setter
isProduction → bool
Check if current environment is production
no setter
isStaging → bool
Check if current environment is staging
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<Environment>
A constant List of the values in this enum, in order of their declaration.