storage property
Active storage backend. Defaults to InMemoryCacheStorage. Replace early in app startup to persist across restarts.
Implementation
static CacheStorage storage = InMemoryCacheStorage();
Active storage backend. Defaults to InMemoryCacheStorage. Replace early in app startup to persist across restarts.
static CacheStorage storage = InMemoryCacheStorage();