DefaultDioProvider class

Default implementation of DioProvider

Implemented types

Constructors

DefaultDioProvider(Dio dio)
Create a provider with a Dio instance
const

Properties

dio Dio
Get the configured Dio instance
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited