ResponseMessage class
Human-readable error messages for response codes
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- BAD_CERTIFICATE → const String
- BAD_GATEWAY → const String
- BAD_REQUEST → const String
- CANCEL → const String
- CONFLICT → const String
- CONNECT_TIMEOUT → const String
- FORBIDDEN → const String
- GATEWAY_TIMEOUT → const String
- INTERNAL_SERVER_ERROR → const String
- METHOD_NOT_ALLOWED → const String
- NO_INTERNET_CONNECTION → const String
- NOT_FOUND → const String
- NOT_IMPLEMENTED → const String
- RECEIVE_TIMEOUT → const String
- SEND_TIMEOUT → const String
- SERVICE_UNAVAILABLE → const String
- SUCCESS → const String
- UNAUTHORISED → const String
- UNKNOWN → const String
- UNPROCESSABLE_ENTITY → const String