UploadFailedState<T, E> class final

Inheritance
Available extensions

Constructors

UploadFailedState(FailureResponse<E> error)
const

Properties

data → T?
Success data, or null
no setterinherited
error → FailureResponse<E>
Error payload, or null
final
hashCode → int
The hash code for this object.
no setterinherited
isError → bool

Available on UploadState<T, E>, provided by the UploadStateX extension

no setter
isFailed → bool

Available on UploadState<T, E>, provided by the UploadStateX extension

no setter
isIdle → bool

Available on UploadState<T, E>, provided by the UploadStateX extension

no setter
isInProgress → bool

Available on UploadState<T, E>, provided by the UploadStateX extension

no setter
isNetworkError → bool

Available on UploadState<T, E>, provided by the UploadStateX extension

no setter
isProcessing → bool

Available on UploadState<T, E>, provided by the UploadStateX extension

no setter
isSuccess → bool

Available on UploadState<T, E>, provided by the UploadStateX extension

no setter
isUploading → bool

Available on UploadState<T, E>, provided by the UploadStateX extension

no setter
progress → double?
Progress in 0.0 – 1.0 when uploading, null otherwise
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

maybeWhen<R>({R idle()?, R uploading(double progress)?, R processing()?, R success(T data)?, R failed(FailureResponse<E> error)?, R networkError()?, required R orElse()}) → R
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
when<R>({required R idle(), required R uploading(double progress), required R processing(), required R success(T data), required R failed(FailureResponse<E> error), required R networkError()}) → R
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited