shouldRetry property
Custom function to determine if request should be retried If null, uses default retry logic
Implementation
final bool Function(DioException)? shouldRetry;
Custom function to determine if request should be retried If null, uses default retry logic
final bool Function(DioException)? shouldRetry;