clearTokens abstract method
Clear all stored tokens (logout)
This should remove both access and refresh tokens from storage.
Implementation
Future<void> clearTokens();
Clear all stored tokens (logout)
This should remove both access and refresh tokens from storage.
Future<void> clearTokens();