ResponseCode class
Standard HTTP and network error codes
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- ACCEPTED → const int
- BAD_CERTIFICATE → const int
- BAD_GATEWAY → const int
- BAD_REQUEST → const int
- CANCEL → const int
- CONFLICT → const int
- CONNECTION_TIMEOUT → const int
- CREATED → const int
- FORBIDDEN → const int
- GATEWAY_TIMEOUT → const int
- INTERNAL_SERVER_ERROR → const int
- METHOD_NOT_ALLOWED → const int
- NO_CONTENT → const int
- NO_INTERNET_CONNECTION → const int
- NOT_FOUND → const int
- NOT_IMPLEMENTED → const int
- RECEIVE_TIMEOUT → const int
- SEND_TIMEOUT → const int
- SERVICE_UNAVAILABLE → const int
- SUCCESS → const int
- UNAUTHORISED → const int
- UNKNOWN → const int
- UNPROCESSABLE_ENTITY → const int