ApiStateWidget<T, E> class
A declarative Flutter widget that renders based on ApiState.
Drop-in replacement for the typical BlocBuilder pattern.
Example:
ApiStateWidget<List<Gallery>, ApiError>(
state: state.apiState,
loadingBuilder: () => const GalleryShimmer(),
emptyBuilder: () => const EmptyGalleries(),
builder: (items) => GalleryGrid(items),
errorBuilder: (msg) => ErrorView(msg),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ApiStateWidget
Constructors
Properties
- builder → Widget Function(T data)
-
Shown when data is available (required)
final
- emptyBuilder → Widget Function()?
-
Shown when data is empty – optional, falls back to SizedBox.shrink()
final
- errorBuilder → Widget Function(String message)
-
Shown when the request failed (required)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idleBuilder → Widget Function()?
-
Shown for idle state – optional, falls back to SizedBox.shrink()
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loadingBuilder → Widget Function()
-
Shown while request is in-flight (required)
final
- networkErrorBuilder → Widget Function()?
-
Shown for connectivity failures – optional, falls back to errorBuilder
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ ApiState<
T, E> -
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited